@@ -513,8 +513,8 @@ auto_launch_now (TrayApplet *ta)
 
    // check last launch time 
    GSettings *um_settings = g_settings_new(SETTINGS_UM_SCHEMA);
-   g_settings_get(um_settings,
-                  SETTINGS_UM_KEY_LAST_LAUNCH, "x", &last_launch);
+   last_launch = g_settings_get_int64(um_settings,
+                                      SETTINGS_UM_KEY_LAST_LAUNCH);
    g_debug_update ("last_launch: %i (%s)", last_launch, ctime(&last_launch));
    g_object_unref(um_settings);
 
@@ -609,7 +609,7 @@ update_check (TrayApplet *ta)
    
    g_debug_update("%s returned %i (security: %i)", UPGRADE_CHECKER, priv->num_upgrades, priv->num_security);
 
-   if (stat("/var/run/reboot-required", &buf) == 0) {
+   if (stat("/run/reboot-required", &buf) == 0) {
       priv->reboot_pending = TRUE;
       g_debug_update("A reboot is currently pending.");
    }
